@@ -1,6 +1,7 @@
 from aertb.core.loaders.dat_loader import DatLoader
 from aertb.core.loaders.bin_loader import BinLoader
 from aertb.core.loaders.aedat_loader import AedatLoader
+from aertb.core.loaders.mat_loader import MatLoader
 from aertb.core.loaders.interface import FileLoaderInterface
 
-__all__ = ['DatLoader', 'BinLoader', 'AedatLoader', 'FileLoaderInterface']
\ No newline at end of file
+__all__ = ['DatLoader', 'BinLoader', 'AedatLoader', 'FileLoaderInterface', 'MatLoader']
\ No newline at end of file
