@@ -16,11 +16,14 @@ from collections import namedtuple
 event_dtype = np.dtype([('x', np.uint16), ('y', np.uint16),
                         ('ts', np.float32), ('p', np.int8)])
 
+event_dtype_ts64 = np.dtype([('x', np.uint16), ('y', np.uint16),
+                             ('ts', np.float64), ('p', np.int8)])
+
 stereo_event_dtype = np.dtype([('x', np.uint16), ('y', np.uint16),
                                ('ts', np.float32), ('p', np.int8),
                                ('x_', np.float32), ('y_', np.float32),
                                ('z_', np.float32), ('d_', np.float32)])
 
-Sample = namedtuple('Sample', ['name', 'label'])
+Sample = namedtuple('Sample', ['group', 'name'])
 EvSample = namedtuple('EvSample', ['label', 'name', 'events'])
 # =============================================================================
\ No newline at end of file
